@@ -4,6 +4,11 @@ from networkx.exception import NetworkXError
 from sortedcontainers import SortedDict
 from networkx.classes.multigraph import MultiGraph
 from networkx.classes.reportviews import NodeView, EdgeView, NodeDataView
+import numpy as np
+import itertools
+import networkx as nx
+import time
+import random
 
 
 class ImpulseGraph(object):
@@ -736,19 +741,16 @@ class ImpulseGraph(object):
         if end is None:
             inclusive = (inclusive[0], True)
 
-        if not u and not v:
-            if not begin or not end:
-                iedges = [iv for iv in self.__search_tree(begin, end, inclusive)]
+        if u is None and v is None:
             # interval filtering
-            else:
-                if begin and end and begin > end:
-                    raise NetworkXError("IntervalGraph: interval end must be bigger than or equal to begin: "
-                                        "begin: {}, end: {}.".format(begin, end))
-                iedges = [iv for iv in self.__search_tree(begin, end, inclusive)]
+            if begin is not None and end is not None and begin > end:
+                raise NetworkXError("IntervalGraph: interval end must be bigger than or equal to begin: "
+                                    "begin: {}, end: {}.".format(begin, end))
+            iedges = [iv for iv in self.__search_tree(begin, end, inclusive)]
 
         else:
             # Node filtering
-            if u and v:
+            if u is not None and v is not None:
                 if u not in self._adj:
                     return []
                 if v not in self._adj[u]:
@@ -765,7 +767,7 @@ class ImpulseGraph(object):
                 iedges = [iv for u in self._adj[v] for iv in self._adj[v][u]]
 
             # Interval filtering
-            if begin and end and begin > end:
+            if begin is not None and end is not None and begin > end:
                 raise NetworkXError("IntervalGraph: interval end must be bigger than or equal to begin: "
                                     "begin: {}, end: {}.".format(begin, end))
             iedges = [iv for iv in iedges if self.__in_interval(iv[2], begin, end, inclusive=inclusive)]
@@ -993,7 +995,7 @@ class ImpulseGraph(object):
         if inclusive == (False, False):
             return t > begin and t < end
 
-    def to_networkx_graph(self, begin, end, inclusive=(True, False), multigraph=False, edge_data=False,
+    def to_networkx_graph(self, begin=None, end=None, inclusive=(True, False), multigraph=False, edge_data=False,
                           edge_timestamp_data=False, node_data=False):
         """Return a networkx Graph or MultiGraph which includes all the nodes and
         edges which have timestamps within the given interval.
@@ -1423,4 +1425,4 @@ class ImpulseGraph(object):
                     line += delimiter + str(key) + '=' + str(edge[1][key])
                 line += '\n'
 
-                file.write(line)
\ No newline at end of file
+                file.write(line)
