@@ -1,8 +1,6 @@
-import dynetworkx as dnx
-import networkx as nx
-from networkx import from_numpy_matrix, from_numpy_array
 import os
-import numpy as np
+import networkx as nx
+import dynetworkx as dnx
 
 current_dir = os.path.dirname(__file__)
 
@@ -180,6 +178,14 @@ def test_intervalgraph_edges_default():
     assert list(G.edges()) == [(3, 4, 5, 6)]
 
 
+def test_intervalgraph_edges_zero():
+    G = dnx.IntervalGraph()
+    G.add_edge(0, 4, 5, 6)
+    G.add_edge(3, 4, 5, 6)
+
+    assert list(G.edges(u=0)) == [(0, 4, 5, 6)]
+
+
 def test_intervalgraph_edges_slice():
     G = dnx.IntervalGraph()
     G.add_edges_from([(1, 2, 10, 11), (2, 4, 11, 12), (6, 4, 19, 20), (2, 4, 15, 16)])
